#
# This is the SPEC file for creating binary RPMs for the Dom0.
#
#
# The Qubes OS Project, http://www.qubes-os.org
#
# Copyright (C) 2010  Joanna Rutkowska <joanna@invisiblethingslab.com>
# Copyright (C) 2010  Rafal Wojtczuk  <rafal@invisiblethingslab.com>
#
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License, or (at your option) any later version.
#
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public
# License along with this library; if not, see <https://www.gnu.org/licenses/>.
#
#

Name:		qubes-core-qrexec-vm
Version:	4.3.1
Release:	1%{dist}
Summary:	The Qubes qrexec files (qube side)

Group:		Qubes
Vendor:		Invisible Things Lab
License:	GPL
URL:		http://www.qubes-os.org

BuildRequires:	gcc
BuildRequires:	pam-devel
BuildRequires:	pandoc
BuildRequires:	qubes-libvchan-devel
BuildRequires:	qubes-core-qrexec-devel
BuildRequires:	lsb-core-noarch
BuildRequires:	systemd-devel

Requires:   python%{python3_pkgversion}
Requires:   qubes-core-qrexec = %{version}-%{release}
# The library is backwards compatible (new library works with old programs)
# but not forwards compatible (old library does not work with new programs)
Requires:   qubes-core-qrexec-libs >= %{version}-%{release}

Provides:   qubes-core-agent-qrexec = 4.1.0-1
Obsoletes:  qubes-core-agent-qrexec < 4.1.0-1

Source0: qubes-core-qrexec-%{version}.tar.gz

Requires: (%{name}-selinux if selinux-policy)

%package selinux
BuildRequires: selinux-policy
BuildRequires: selinux-policy-devel
%{?selinux_requires}
Requires(post): qubes-core-agent-selinux
Summary: SELinux policies for qrexec
License: GPLv2+

%description selinux
The SELinux policies for qrexec.  You need this package if you want to have
SELinux enforcing in a qube.

%description
The Qubes qrexec files for installation on a qube.

%prep
%setup -qn qubes-core-qrexec-%{version}

%build
%{?set_build_flags}
make all-vm all-vm-selinux
#make -C doc PYTHON=%{__python3} SPHINXBUILD=sphinx-build-%{python3_version} man

%install
make install-vm install-vm-selinux \
    DESTDIR=$RPM_BUILD_ROOT \
    UNITDIR=%{_unitdir} \
    PYTHON_SITEPATH=%{python3_sitelib} \
    SYSCONFDIR=%{_sysconfdir}

#make -C doc DESTDIR=$RPM_BUILD_ROOT \
#    PYTHON=%{__python3} SPHINXBUILD=sphinx-build-%{python3_version} \
#    install

%clean
rm -rf $RPM_BUILD_ROOT
rm -f %{name}-%{version}

%post
%systemd_post qubes-qrexec-agent.service

%preun
%systemd_preun qubes-qrexec-agent.service

%post selinux
%selinux_modules_install %{_datadir}/selinux/packages/qubes-core-qrexec.pp || :

%postun selinux
if [ "$1" -eq 0 ]; then
    %selinux_modules_uninstall %{_datadir}/selinux/packages/qubes-core-qrexec.pp
fi || :

%posttrans selinux
%selinux_relabel_post
exit 0

%posttrans
# when upgrading from R4.0, %%postun of qubes-core-agent-qrexec will revert
# %%post of this package. Redo the action in %%posttrans
%systemd_post qubes-qrexec-agent.service
# and then start it back
if systemctl is-enabled qubes-qrexec-agent.service >/dev/null 2>&1; then
    systemctl start qubes-qrexec-agent.service
fi

%files
%defattr(-,root,root,-)
%config(noreplace) /etc/pam.d/qrexec
%dir /etc/qubes
%dir /etc/qubes/rpc-config
/etc/qubes/rpc-config/README

%{_bindir}/qrexec-client-vm
%{_bindir}/qrexec-fork-server

%{_mandir}/man1/qrexec-client-vm.1*

%dir /usr/lib/qubes
/usr/lib/qubes/qrexec-agent
/usr/lib/qubes/qrexec-client-vm
/usr/lib/qubes/qrexec_client_vm
/lib/systemd/system/qubes-qrexec-agent.service

%files selinux
%{_datadir}/selinux/devel/include/contrib/ipp-qubes-core-qrexec.if
%{_datadir}/selinux/packages/qubes-core-qrexec.pp

%changelog
* Wed Dec 11 2024 Qubes OS Team <qubes-devel@googlegroups.com>
- For complete changelog see: https://github.com/QubesOS/qubes-core-qrexec.git

* Wed Dec 11 2024 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 0e35fa4
- version 4.3.1

* Tue Dec 10 2024 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - df25090
- Add a test for qrexec-client race condition

* Tue Dec 03 2024 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 66c1519
- Try to retrieve exit code of a failed service call

* Mon Oct 14 2024 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - 5c028c0
- Blacken the whole repository and add CI job

* Wed Oct 09 2024 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - ba1c157
- version 4.3.0

* Wed Oct 09 2024 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - c7f4b74
- ci: switch to R4.3

* Wed Oct 09 2024 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 417d141
- rpm: adjust version constraint for UUID identification

* Wed Oct 09 2024 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 185863e
- daemon: document --uuid and require it to start

* Wed Oct 09 2024 Ali Mirjamali <ali@mirjamali.com> - abe8eb5
- Pipe `qrexec-client(-vm) --help` output to stdout

* Wed Sep 25 2024 Ali Mirjamali <ali@mirjamali.com> - 098eb78
- Provide clear error on invalid policy file name

* Wed Sep 25 2024 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - da67c26
- Remove unused test

* Wed Sep 25 2024 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - e485ee5
- pylint: deal with too-many-positional-arguments

* Wed Sep 25 2024 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - 0b4b892
- qrexec-client-vm: fix missing option in usage and reorder it

* Sat Sep 14 2024 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 5acc518
- daemon: log a bit more info on errors

* Fri Sep 13 2024 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - 34211a2
- tests: fix POLICY_PROGRAM and update documentation

* Sun Aug 18 2024 Demi Marie Obenour <demi@invisiblethingslab.com> - 578de59
- Implement UUID support in qrexec

* Sun Aug 18 2024 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 98e0acd
- daemon: restore SIGTERM default handler in child process

* Sat Aug 17 2024 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - fedd1cf
- version 4.2.22

* Wed Jul 24 2024 Piotr Bartman-Szwarc <prbartman@invisiblethingslab.com> - 45527be
- actually sanitize service name

* Fri Jul 05 2024 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 9e09690
- version 4.2.21

* Mon Jul 01 2024 Ali Mirjamali <ali@mirjamali.com> - 0589ae8
- Support substring matching in qube name text fields

* Sat Jun 29 2024 Demi Marie Obenour <demi@invisiblethingslab.com> - 966e383
- Use fully-qualified exception names in .pylintrc

* Sat Jun 29 2024 Demi Marie Obenour <demi@invisiblethingslab.com> - f2ed5fb
- Support additional policy directories

* Thu Jun 27 2024 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 60b54a6
- tests: policy cache reacting to moving files

* Thu Jun 27 2024 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 1a5cf9d
- policy-daemon: invalidate cache on file move too

* Thu Jun 27 2024 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - c17ee39
- Make pylint happy

* Fri Jun 14 2024 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 7a2155d
- version 4.2.20

* Wed Jun 12 2024 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - bab74d5
- Downgrade errors about incompatible service config to warnings

* Tue May 28 2024 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - c87b9e7
- Remove redundant log line

* Tue May 28 2024 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 6760cfa
- Make stderr line-buffered for logging

* Tue May 28 2024 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 1e05472
- daemon: attempt starting target vm only if not running yet

* Tue May 28 2024 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 0d5efaa
- doc: fix class names in API docs

* Wed May 22 2024 Demi Marie Obenour <demi@invisiblethingslab.com> - 2b71adb
- Avoid closing stderr when MSG_DATA_EXIT_CODE is received

* Wed May 22 2024 Demi Marie Obenour <demi@invisiblethingslab.com> - 0701529
- Send EOF whenever closing stdout

* Wed May 22 2024 Demi Marie Obenour <demi@invisiblethingslab.com> - 50bc9db
- Send EOF on stdout when exiting due to EOF on stdin

* Wed May 22 2024 Demi Marie Obenour <demi@invisiblethingslab.com> - 3658079
- Always send EOF on stderr

* Wed May 22 2024 Demi Marie Obenour <demi@invisiblethingslab.com> - c0f4d28
- Command and API documentation

* Sun May 19 2024 Demi Marie Obenour <demi@invisiblethingslab.com> - 9d07581
- tests: Actually check that stdout was expected value

* Sat May 18 2024 Ben Grande <ben.grande.b@gmail.com> - 5ced777
- Document rpc config until exit-on-server-eof

* Fri May 17 2024 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 110f840
- Mute pylint false positive

* Thu May 16 2024 Demi Marie Obenour <demi@invisiblethingslab.com> - 49f9710
- qrexec-daemon: Use close_range where possible

* Thu May 09 2024 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 43f49f0
- version 4.2.19

* Mon May 06 2024 Marta Marczykowska-Górecka <marmarta@invisiblethingslab.com> - 1a402fe
- Remove deprecated pkg_resources, replace with importlib

* Sun May 05 2024 Demi Marie Obenour <demi@invisiblethingslab.com> - 64d6e06
- Test if a service config directory itself is invalid

* Sun May 05 2024 Demi Marie Obenour <demi@invisiblethingslab.com> - c6f9a2f
- Fail early if the service config cannot be found

* Sun May 05 2024 Demi Marie Obenour <demi@invisiblethingslab.com> - 9114fb3
- Avoid passing stderr_fd to handle_data_client

* Sun May 05 2024 Demi Marie Obenour <demi@invisiblethingslab.com> - 8b683a8
- tests: do not write to maybe-closed socket

* Sun May 05 2024 Demi Marie Obenour <demi@invisiblethingslab.com> - a60c40c
- Add support for exiting on client or service EOF

* Sun May 05 2024 Demi Marie Obenour <demi@invisiblethingslab.com> - 129b5dd
- Better logging for socket services

* Sat May 04 2024 Demi Marie Obenour <demi@invisiblethingslab.com> - cdf92b7
- Check at startup that standard streams are open

